@@ -19,23 +19,14 @@ def init_parser() -> argparse.ArgumentParser:
         - ArgumentParser with configured arguments.
     """
     parser = argparse.ArgumentParser(
-        prog="Boost", description="A modern python multiplatform build system"
-    )
-    parser.add_argument(
-        "boost", help="Boost operation", nargs="?", default="", type=str
+        prog="Boost",
+        description="Boost is a simple build system that aims to create an interface \
+            for shell command substitution across different operative systems.",
     )
+    parser.add_argument("boost", help="Boost target", nargs="?", default="", type=str)
     return parser
 
 
-def validate_boost() -> dict:
-    """Reads and validates boost.yaml file.
-
-    returns:
-        - dict containing parsed and validated yaml.
-        - bool as false in case yaml file could not be readen or validated.
-    """
-
-
 def call_command(cmd: str, args: List[str]) -> dict:
     """Execute given command.
 
@@ -130,7 +121,7 @@ def main() -> int:
     else:
         boost = args.boost
 
-    variables = re.findall("{.*}", boost_data["boost"][boost])
+    variables = re.findall("{.*?}", boost_data["boost"][boost])
     commands = boost_data["boost"][boost].strip().split("\n")
     total_commands = len(commands)
     print(Fore.CYAN + f"Boosting {boost} - {total_commands} commands")
@@ -141,7 +132,7 @@ def main() -> int:
         return 1
 
     for i, cmd in enumerate(commands):
-        variables = re.findall("{.*}", cmd)
+        variables = re.findall("{.*?}", cmd)
         for var in variables:
             cmd = cmd.replace(var, storage[var])
         print(Fore.GREEN + f"-> [{i + 1}/{total_commands}] - {cmd}")
